@@ -13,7 +13,7 @@ package Printer::ESCPOS;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '1.002'; # VERSION
+our $VERSION = '1.003'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -159,7 +159,10 @@ Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printe
 =begin html
 
 <p>
+<img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/shantanubhadoria/perl-Printer-ESCPOS"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Printer-ESCPOS.svg?branch=build/master" alt="Travis status" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Printer-ESCPOS%201.003"><img src="https://badgedepot.code301.com/badge/cpantesters/Printer-ESCPOS/1.003" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Printer-ESCPOS-1.003"><img src="https://badgedepot.code301.com/badge/kwalitee/Printer-ESCPOS/1.003" alt="Distribution kwalitee" /></a>
 <a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
 </p>
 
@@ -167,7 +170,7 @@ Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printe
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 SYNOPSIS
 
